==> openplugincore-0.6.0.tar.gz: openplugincore-0.6.0/openplugincore/openplugin_memo.py <==
import requests
from openplugincore import OpenPlugin
import os

class OpenPluginMemo:
    def __init__(self):
        self.plugins = {}
        self.plugins_directory = None

    def init(self):
        self.plugins_directory = {}
        plugins_url = 'https://raw.githubusercontent.com/CakeCrusher/openplugin/main/migrations/plugin_store/openplugins.json'
        response = requests.get(plugins_url)
        if not response.ok:
            raise Exception(f"Unable to fetch plugins from github url '{plugins_url}'")
        # add all json key and values to pluginsDirectory
        plugins = response.json()
        for key, value in plugins.items():
            self.plugins_directory[key] = value
        print('MEMO READY')

    def init_plugin(self, plugin_name):
        if not self.plugins_directory:
            raise Exception('Plugin directory not initialized')
        plugin_url = self.plugins_directory.get(plugin_name)
        if plugin_url is None:
            raise Exception('Plugin not found')
        plugin = OpenPlugin(plugin_name=plugin_name, openai_api_key=os.getenv('OPENAI_API_KEY'))
        plugin.init()
        self.add_plugin(plugin)
        return plugin

    # method to add an OpenPlugin to the plugins map
    def add_plugin(self, plugin):
        if not plugin.name:
            raise Exception('Plugin name not found')
        self.plugins[plugin.name] = plugin

    # method to remove an OpenPlugin from the plugins map
    def remove_plugin(self, plugin_name):
        self.plugins.pop(plugin_name, None)

    # method to get an OpenPlugin by name
    def get_plugin(self, plugin_name):
        return self.plugins.get(plugin_name)

==> openplugincore-0.7.2.tar.gz: openplugincore-0.7.2/openplugincore/openplugin_memo.py <==
# C:\Projects\OpenPlugin\openplugin\pypi-core\openplugincore\openplugin_memo.py

import requests
from openplugincore import OpenPlugin
import os

class OpenPluginMemo:
    def __init__(self):
        self.plugins = {}
        self.plugins_directory = None

    def init(self):
        self.plugins_directory = {}
        plugins_url = 'https://raw.githubusercontent.com/CakeCrusher/openplugin/main/migrations/plugin_store/openplugins.json'
        response = requests.get(plugins_url)
        if not response.ok:
            raise Exception(f"Unable to fetch plugins from github url '{plugins_url}'")
        # add all json key and values to pluginsDirectory
        plugins = response.json()
        for key, value in plugins.items():
            self.plugins_directory[key] = value
        print('MEMO READY')

    def init_openplugin(self, plugin_name=None, root_url=None):
        if not plugin_name and not root_url:
            raise Exception('Plugin name not found')
        plugin = OpenPlugin(plugin_name=plugin_name, root_url=root_url, openai_api_key=os.getenv('OPENAI_API_KEY'))
        plugin.init()
        return plugin

    def init_plugin(self, plugin_name):
        if not self.plugins_directory:
            raise Exception('Plugin directory not initialized')
        plugin_url = self.plugins_directory.get(plugin_name)
        if plugin_url is None:
            raise Exception('Plugin not found')
        plugin = self.init_openplugin(plugin_name=plugin_name)
        self.add_plugin(plugin)
        return plugin
    
    # method to add an OpenPlugin to the plugins map
    def add_plugin(self, plugin):
        if not plugin.name:
            raise Exception('Plugin name not found')
        self.plugins[plugin.name] = plugin

    # method to remove an OpenPlugin from the plugins map
    def remove_plugin(self, plugin_name):
        self.plugins.pop(plugin_name, None)

    # method to get an OpenPlugin by name
    def get_plugin(self, plugin_name):
        return self.plugins.get(plugin_name)
